from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.StepBasic import *
from OCC.Core.StepRepr import *
from OCC.Core.TCollection import *


class StepAP203_Array1OfApprovedItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_ApprovedItem: ...
    def __setitem__(self, index: int, value: StepAP203_ApprovedItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_ApprovedItem]: ...
    def next(self) -> StepAP203_ApprovedItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_ApprovedItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_ApprovedItem: ...
    def Last(self) -> StepAP203_ApprovedItem: ...
    def Value(self, theIndex: int) -> StepAP203_ApprovedItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_ApprovedItem) -> None: ...

class StepAP203_Array1OfCertifiedItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_CertifiedItem: ...
    def __setitem__(self, index: int, value: StepAP203_CertifiedItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_CertifiedItem]: ...
    def next(self) -> StepAP203_CertifiedItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_CertifiedItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_CertifiedItem: ...
    def Last(self) -> StepAP203_CertifiedItem: ...
    def Value(self, theIndex: int) -> StepAP203_CertifiedItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_CertifiedItem) -> None: ...

class StepAP203_Array1OfChangeRequestItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_ChangeRequestItem: ...
    def __setitem__(self, index: int, value: StepAP203_ChangeRequestItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_ChangeRequestItem]: ...
    def next(self) -> StepAP203_ChangeRequestItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_ChangeRequestItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_ChangeRequestItem: ...
    def Last(self) -> StepAP203_ChangeRequestItem: ...
    def Value(self, theIndex: int) -> StepAP203_ChangeRequestItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_ChangeRequestItem) -> None: ...

class StepAP203_Array1OfClassifiedItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_ClassifiedItem: ...
    def __setitem__(self, index: int, value: StepAP203_ClassifiedItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_ClassifiedItem]: ...
    def next(self) -> StepAP203_ClassifiedItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_ClassifiedItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_ClassifiedItem: ...
    def Last(self) -> StepAP203_ClassifiedItem: ...
    def Value(self, theIndex: int) -> StepAP203_ClassifiedItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_ClassifiedItem) -> None: ...

class StepAP203_Array1OfContractedItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_ContractedItem: ...
    def __setitem__(self, index: int, value: StepAP203_ContractedItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_ContractedItem]: ...
    def next(self) -> StepAP203_ContractedItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_ContractedItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_ContractedItem: ...
    def Last(self) -> StepAP203_ContractedItem: ...
    def Value(self, theIndex: int) -> StepAP203_ContractedItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_ContractedItem) -> None: ...

class StepAP203_Array1OfDateTimeItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_DateTimeItem: ...
    def __setitem__(self, index: int, value: StepAP203_DateTimeItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_DateTimeItem]: ...
    def next(self) -> StepAP203_DateTimeItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_DateTimeItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_DateTimeItem: ...
    def Last(self) -> StepAP203_DateTimeItem: ...
    def Value(self, theIndex: int) -> StepAP203_DateTimeItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_DateTimeItem) -> None: ...

class StepAP203_Array1OfPersonOrganizationItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_PersonOrganizationItem: ...
    def __setitem__(self, index: int, value: StepAP203_PersonOrganizationItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_PersonOrganizationItem]: ...
    def next(self) -> StepAP203_PersonOrganizationItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_PersonOrganizationItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_PersonOrganizationItem: ...
    def Last(self) -> StepAP203_PersonOrganizationItem: ...
    def Value(self, theIndex: int) -> StepAP203_PersonOrganizationItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_PersonOrganizationItem) -> None: ...

class StepAP203_Array1OfSpecifiedItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_SpecifiedItem: ...
    def __setitem__(self, index: int, value: StepAP203_SpecifiedItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_SpecifiedItem]: ...
    def next(self) -> StepAP203_SpecifiedItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_SpecifiedItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_SpecifiedItem: ...
    def Last(self) -> StepAP203_SpecifiedItem: ...
    def Value(self, theIndex: int) -> StepAP203_SpecifiedItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_SpecifiedItem) -> None: ...

class StepAP203_Array1OfStartRequestItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_StartRequestItem: ...
    def __setitem__(self, index: int, value: StepAP203_StartRequestItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_StartRequestItem]: ...
    def next(self) -> StepAP203_StartRequestItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_StartRequestItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_StartRequestItem: ...
    def Last(self) -> StepAP203_StartRequestItem: ...
    def Value(self, theIndex: int) -> StepAP203_StartRequestItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_StartRequestItem) -> None: ...

class StepAP203_Array1OfWorkItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP203_WorkItem: ...
    def __setitem__(self, index: int, value: StepAP203_WorkItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP203_WorkItem]: ...
    def next(self) -> StepAP203_WorkItem: ...
    __next__ = next
    def Init(self, theValue: StepAP203_WorkItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP203_WorkItem: ...
    def Last(self) -> StepAP203_WorkItem: ...
    def Value(self, theIndex: int) -> StepAP203_WorkItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP203_WorkItem) -> None: ...

class StepAP203_ApprovedItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def Certification(self) -> StepBasic_Certification: ...
	def Change(self) -> StepAP203_Change: ...
	def ChangeRequest(self) -> StepAP203_ChangeRequest: ...
	def ConfigurationEffectivity(self) -> StepRepr_ConfigurationEffectivity: ...
	def ConfigurationItem(self) -> StepRepr_ConfigurationItem: ...
	def Contract(self) -> StepBasic_Contract: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...
	def SecurityClassification(self) -> StepBasic_SecurityClassification: ...
	def StartRequest(self) -> StepAP203_StartRequest: ...
	def StartWork(self) -> StepAP203_StartWork: ...

class StepAP203_CcDesignApproval(StepBasic_ApprovalAssignment):
	def __init__(self) -> None: ...
	def Init(self, aApprovalAssignment_AssignedApproval: StepBasic_Approval, aItems: StepAP203_HArray1OfApprovedItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfApprovedItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfApprovedItem) -> None: ...

class StepAP203_CcDesignCertification(StepBasic_CertificationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aCertificationAssignment_AssignedCertification: StepBasic_Certification, aItems: StepAP203_HArray1OfCertifiedItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfCertifiedItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfCertifiedItem) -> None: ...

class StepAP203_CcDesignContract(StepBasic_ContractAssignment):
	def __init__(self) -> None: ...
	def Init(self, aContractAssignment_AssignedContract: StepBasic_Contract, aItems: StepAP203_HArray1OfContractedItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfContractedItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfContractedItem) -> None: ...

class StepAP203_CcDesignDateAndTimeAssignment(StepBasic_DateAndTimeAssignment):
	def __init__(self) -> None: ...
	def Init(self, aDateAndTimeAssignment_AssignedDateAndTime: StepBasic_DateAndTime, aDateAndTimeAssignment_Role: StepBasic_DateTimeRole, aItems: StepAP203_HArray1OfDateTimeItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfDateTimeItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfDateTimeItem) -> None: ...

class StepAP203_CcDesignPersonAndOrganizationAssignment(StepBasic_PersonAndOrganizationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aPersonAndOrganizationAssignment_AssignedPersonAndOrganization: StepBasic_PersonAndOrganization, aPersonAndOrganizationAssignment_Role: StepBasic_PersonAndOrganizationRole, aItems: StepAP203_HArray1OfPersonOrganizationItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfPersonOrganizationItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfPersonOrganizationItem) -> None: ...

class StepAP203_CcDesignSecurityClassification(StepBasic_SecurityClassificationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aSecurityClassificationAssignment_AssignedSecurityClassification: StepBasic_SecurityClassification, aItems: StepAP203_HArray1OfClassifiedItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfClassifiedItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfClassifiedItem) -> None: ...

class StepAP203_CcDesignSpecificationReference(StepBasic_DocumentReference):
	def __init__(self) -> None: ...
	def Init(self, aDocumentReference_AssignedDocument: StepBasic_Document, aDocumentReference_Source: TCollection_HAsciiString, aItems: StepAP203_HArray1OfSpecifiedItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfSpecifiedItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfSpecifiedItem) -> None: ...

class StepAP203_CertifiedItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def SuppliedPartRelationship(self) -> StepRepr_SuppliedPartRelationship: ...

class StepAP203_Change(StepBasic_ActionAssignment):
	def __init__(self) -> None: ...
	def Init(self, aActionAssignment_AssignedAction: StepBasic_Action, aItems: StepAP203_HArray1OfWorkItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfWorkItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfWorkItem) -> None: ...

class StepAP203_ChangeRequest(StepBasic_ActionRequestAssignment):
	def __init__(self) -> None: ...
	def Init(self, aActionRequestAssignment_AssignedActionRequest: StepBasic_VersionedActionRequest, aItems: StepAP203_HArray1OfChangeRequestItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfChangeRequestItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfChangeRequestItem) -> None: ...

class StepAP203_ChangeRequestItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...

class StepAP203_ClassifiedItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def AssemblyComponentUsage(self) -> StepRepr_AssemblyComponentUsage: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...

class StepAP203_ContractedItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...

class StepAP203_DateTimeItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def ApprovalPersonOrganization(self) -> StepBasic_ApprovalPersonOrganization: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def Certification(self) -> StepBasic_Certification: ...
	def Change(self) -> StepAP203_Change: ...
	def ChangeRequest(self) -> StepAP203_ChangeRequest: ...
	def Contract(self) -> StepBasic_Contract: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def SecurityClassification(self) -> StepBasic_SecurityClassification: ...
	def StartRequest(self) -> StepAP203_StartRequest: ...
	def StartWork(self) -> StepAP203_StartWork: ...

class StepAP203_PersonOrganizationItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def Change(self) -> StepAP203_Change: ...
	def ChangeRequest(self) -> StepAP203_ChangeRequest: ...
	def ConfigurationItem(self) -> StepRepr_ConfigurationItem: ...
	def Contract(self) -> StepBasic_Contract: ...
	def Product(self) -> StepBasic_Product: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...
	def SecurityClassification(self) -> StepBasic_SecurityClassification: ...
	def StartRequest(self) -> StepAP203_StartRequest: ...
	def StartWork(self) -> StepAP203_StartWork: ...

class StepAP203_SpecifiedItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...

class StepAP203_StartRequest(StepBasic_ActionRequestAssignment):
	def __init__(self) -> None: ...
	def Init(self, aActionRequestAssignment_AssignedActionRequest: StepBasic_VersionedActionRequest, aItems: StepAP203_HArray1OfStartRequestItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfStartRequestItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfStartRequestItem) -> None: ...

class StepAP203_StartRequestItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...

class StepAP203_StartWork(StepBasic_ActionAssignment):
	def __init__(self) -> None: ...
	def Init(self, aActionAssignment_AssignedAction: StepBasic_Action, aItems: StepAP203_HArray1OfWorkItem) -> None: ...
	def Items(self) -> StepAP203_HArray1OfWorkItem: ...
	def SetItems(self, Items: StepAP203_HArray1OfWorkItem) -> None: ...

class StepAP203_WorkItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...

# harray1 classes

class StepAP203_HArray1OfSpecifiedItem(StepAP203_Array1OfSpecifiedItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfSpecifiedItem: ...


class StepAP203_HArray1OfPersonOrganizationItem(StepAP203_Array1OfPersonOrganizationItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfPersonOrganizationItem: ...


class StepAP203_HArray1OfChangeRequestItem(StepAP203_Array1OfChangeRequestItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfChangeRequestItem: ...


class StepAP203_HArray1OfContractedItem(StepAP203_Array1OfContractedItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfContractedItem: ...


class StepAP203_HArray1OfCertifiedItem(StepAP203_Array1OfCertifiedItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfCertifiedItem: ...


class StepAP203_HArray1OfStartRequestItem(StepAP203_Array1OfStartRequestItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfStartRequestItem: ...


class StepAP203_HArray1OfDateTimeItem(StepAP203_Array1OfDateTimeItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfDateTimeItem: ...


class StepAP203_HArray1OfApprovedItem(StepAP203_Array1OfApprovedItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfApprovedItem: ...


class StepAP203_HArray1OfWorkItem(StepAP203_Array1OfWorkItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfWorkItem: ...


class StepAP203_HArray1OfClassifiedItem(StepAP203_Array1OfClassifiedItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP203_Array1OfClassifiedItem: ...

# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *


class Geom2d_Geometry(Standard_Transient):
	def Copy(self) -> Geom2d_Geometry: ...
	@overload
	def Mirror(self, P: gp_Pnt2d) -> None: ...
	@overload
	def Mirror(self, A: gp_Ax2d) -> None: ...
	@overload
	def Mirrored(self, P: gp_Pnt2d) -> Geom2d_Geometry: ...
	@overload
	def Mirrored(self, A: gp_Ax2d) -> Geom2d_Geometry: ...
	def Rotate(self, P: gp_Pnt2d, Ang: float) -> None: ...
	def Rotated(self, P: gp_Pnt2d, Ang: float) -> Geom2d_Geometry: ...
	def Scale(self, P: gp_Pnt2d, S: float) -> None: ...
	def Scaled(self, P: gp_Pnt2d, S: float) -> Geom2d_Geometry: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def Transformed(self, T: gp_Trsf2d) -> Geom2d_Geometry: ...
	@overload
	def Translate(self, V: gp_Vec2d) -> None: ...
	@overload
	def Translate(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def Translated(self, V: gp_Vec2d) -> Geom2d_Geometry: ...
	@overload
	def Translated(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> Geom2d_Geometry: ...

class Geom2d_Transformation(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, T: gp_Trsf2d) -> None: ...
	def Copy(self) -> Geom2d_Transformation: ...
	def Form(self) -> gp_TrsfForm: ...
	def Invert(self) -> None: ...
	def Inverted(self) -> Geom2d_Transformation: ...
	def IsNegative(self) -> bool: ...
	def Multiplied(self, Other: Geom2d_Transformation) -> Geom2d_Transformation: ...
	def Multiply(self, Other: Geom2d_Transformation) -> None: ...
	def Power(self, N: int) -> None: ...
	def Powered(self, N: int) -> Geom2d_Transformation: ...
	def PreMultiply(self, Other: Geom2d_Transformation) -> None: ...
	def ScaleFactor(self) -> float: ...
	@overload
	def SetMirror(self, P: gp_Pnt2d) -> None: ...
	@overload
	def SetMirror(self, A: gp_Ax2d) -> None: ...
	def SetRotation(self, P: gp_Pnt2d, Ang: float) -> None: ...
	def SetScale(self, P: gp_Pnt2d, S: float) -> None: ...
	@overload
	def SetTransformation(self, FromSystem1: gp_Ax2d, ToSystem2: gp_Ax2d) -> None: ...
	@overload
	def SetTransformation(self, ToSystem: gp_Ax2d) -> None: ...
	@overload
	def SetTranslation(self, V: gp_Vec2d) -> None: ...
	@overload
	def SetTranslation(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def SetTrsf2d(self, T: gp_Trsf2d) -> None: ...
	def Transforms(self) -> Tuple[float, float]: ...
	def Trsf2d(self) -> gp_Trsf2d: ...
	def Value(self, Row: int, Col: int) -> float: ...

class Geom2d_AxisPlacement(Geom2d_Geometry):
	@overload
	def __init__(self, A: gp_Ax2d) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, V: gp_Dir2d) -> None: ...
	def Angle(self, Other: Geom2d_AxisPlacement) -> float: ...
	def Ax2d(self) -> gp_Ax2d: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def Direction(self) -> gp_Dir2d: ...
	def Location(self) -> gp_Pnt2d: ...
	def Reverse(self) -> None: ...
	def Reversed(self) -> Geom2d_AxisPlacement: ...
	def SetAxis(self, A: gp_Ax2d) -> None: ...
	def SetDirection(self, V: gp_Dir2d) -> None: ...
	def SetLocation(self, P: gp_Pnt2d) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...

class Geom2d_Curve(Geom2d_Geometry):
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def FirstParameter(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf2d) -> float: ...
	def Period(self) -> float: ...
	def Reverse(self) -> None: ...
	def Reversed(self) -> Geom2d_Curve: ...
	def ReversedParameter(self, U: float) -> float: ...
	def TransformedParameter(self, U: float, T: gp_Trsf2d) -> float: ...
	def Value(self, U: float) -> gp_Pnt2d: ...

class Geom2d_Point(Geom2d_Geometry):
	def Coord(self) -> Tuple[float, float]: ...
	def Distance(self, Other: Geom2d_Point) -> float: ...
	def Pnt2d(self) -> gp_Pnt2d: ...
	def SquareDistance(self, Other: Geom2d_Point) -> float: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...

class Geom2d_Vector(Geom2d_Geometry):
	def Angle(self, Other: Geom2d_Vector) -> float: ...
	def Coord(self) -> Tuple[float, float]: ...
	def Crossed(self, Other: Geom2d_Vector) -> float: ...
	def Dot(self, Other: Geom2d_Vector) -> float: ...
	def Magnitude(self) -> float: ...
	def Reverse(self) -> None: ...
	def Reversed(self) -> Geom2d_Vector: ...
	def SquareMagnitude(self) -> float: ...
	def Vec2d(self) -> gp_Vec2d: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...

class Geom2d_BoundedCurve(Geom2d_Curve):
	def EndPoint(self) -> gp_Pnt2d: ...
	def StartPoint(self) -> gp_Pnt2d: ...

class Geom2d_CartesianPoint(Geom2d_Point):
	@overload
	def __init__(self, P: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, X: float, Y: float) -> None: ...
	def Coord(self) -> Tuple[float, float]: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def Pnt2d(self) -> gp_Pnt2d: ...
	def SetCoord(self, X: float, Y: float) -> None: ...
	def SetPnt2d(self, P: gp_Pnt2d) -> None: ...
	def SetX(self, X: float) -> None: ...
	def SetY(self, Y: float) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...

class Geom2d_Conic(Geom2d_Curve):
	def Continuity(self) -> GeomAbs_Shape: ...
	def Eccentricity(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def Location(self) -> gp_Pnt2d: ...
	def Position(self) -> gp_Ax22d: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetAxis(self, theA: gp_Ax22d) -> None: ...
	def SetLocation(self, theP: gp_Pnt2d) -> None: ...
	def SetXAxis(self, theAX: gp_Ax2d) -> None: ...
	def SetYAxis(self, theAY: gp_Ax2d) -> None: ...
	def XAxis(self) -> gp_Ax2d: ...
	def YAxis(self) -> gp_Ax2d: ...

class Geom2d_Direction(Geom2d_Vector):
	@overload
	def __init__(self, X: float, Y: float) -> None: ...
	@overload
	def __init__(self, V: gp_Dir2d) -> None: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def Crossed(self, Other: Geom2d_Vector) -> float: ...
	def Dir2d(self) -> gp_Dir2d: ...
	def Magnitude(self) -> float: ...
	def SetCoord(self, X: float, Y: float) -> None: ...
	def SetDir2d(self, V: gp_Dir2d) -> None: ...
	def SetX(self, X: float) -> None: ...
	def SetY(self, Y: float) -> None: ...
	def SquareMagnitude(self) -> float: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...

class Geom2d_Line(Geom2d_Curve):
	@overload
	def __init__(self, A: gp_Ax2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, V: gp_Dir2d) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Direction(self) -> gp_Dir2d: ...
	def Distance(self, P: gp_Pnt2d) -> float: ...
	def FirstParameter(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Lin2d(self) -> gp_Lin2d: ...
	def Location(self) -> gp_Pnt2d: ...
	def ParametricTransformation(self, T: gp_Trsf2d) -> float: ...
	def Position(self) -> gp_Ax2d: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetDirection(self, V: gp_Dir2d) -> None: ...
	def SetLin2d(self, L: gp_Lin2d) -> None: ...
	def SetLocation(self, P: gp_Pnt2d) -> None: ...
	def SetPosition(self, A: gp_Ax2d) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf2d) -> float: ...

class Geom2d_OffsetCurve(Geom2d_Curve):
	def __init__(self, C: Geom2d_Curve, Offset: float, isNotCheckC0: Optional[bool] = False) -> None: ...
	def BasisCurve(self) -> Geom2d_Curve: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def FirstParameter(self) -> float: ...
	def GetBasisCurveContinuity(self) -> GeomAbs_Shape: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Offset(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf2d) -> float: ...
	def Period(self) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetBasisCurve(self, C: Geom2d_Curve, isNotCheckC0: Optional[bool] = False) -> None: ...
	def SetOffsetValue(self, D: float) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf2d) -> float: ...

class Geom2d_VectorWithMagnitude(Geom2d_Vector):
	@overload
	def __init__(self, V: gp_Vec2d) -> None: ...
	@overload
	def __init__(self, X: float, Y: float) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def Add(self, Other: Geom2d_Vector) -> None: ...
	def Added(self, Other: Geom2d_Vector) -> Geom2d_VectorWithMagnitude: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def Crossed(self, Other: Geom2d_Vector) -> float: ...
	def Divide(self, Scalar: float) -> None: ...
	def Divided(self, Scalar: float) -> Geom2d_VectorWithMagnitude: ...
	def Magnitude(self) -> float: ...
	def Multiplied(self, Scalar: float) -> Geom2d_VectorWithMagnitude: ...
	def Multiply(self, Scalar: float) -> None: ...
	def Normalize(self) -> None: ...
	def Normalized(self) -> Geom2d_VectorWithMagnitude: ...
	def SetCoord(self, X: float, Y: float) -> None: ...
	def SetVec2d(self, V: gp_Vec2d) -> None: ...
	def SetX(self, X: float) -> None: ...
	def SetY(self, Y: float) -> None: ...
	def SquareMagnitude(self) -> float: ...
	def Subtract(self, Other: Geom2d_Vector) -> None: ...
	def Subtracted(self, Other: Geom2d_Vector) -> Geom2d_VectorWithMagnitude: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...

class Geom2d_BSplineCurve(Geom2d_BoundedCurve):
	@overload
	def __init__(self, Poles: TColgp_Array1OfPnt2d, Knots: TColStd_Array1OfReal, Multiplicities: TColStd_Array1OfInteger, Degree: int, Periodic: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Multiplicities: TColStd_Array1OfInteger, Degree: int, Periodic: Optional[bool] = False) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Degree(self) -> int: ...
	def EndPoint(self) -> gp_Pnt2d: ...
	def FirstParameter(self) -> float: ...
	def FirstUKnotIndex(self) -> int: ...
	def IncreaseDegree(self, Degree: int) -> None: ...
	@overload
	def IncreaseMultiplicity(self, Index: int, M: int) -> None: ...
	@overload
	def IncreaseMultiplicity(self, I1: int, I2: int, M: int) -> None: ...
	def IncrementMultiplicity(self, I1: int, I2: int, M: int) -> None: ...
	def InsertKnot(self, U: float, M: Optional[int] = 1, ParametricTolerance: Optional[float] = 0.0) -> None: ...
	def InsertKnots(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, ParametricTolerance: Optional[float] = 0.0, Add: Optional[bool] = False) -> None: ...
	def InsertPoleAfter(self, Index: int, P: gp_Pnt2d, Weight: Optional[float] = 1.0) -> None: ...
	def InsertPoleBefore(self, Index: int, P: gp_Pnt2d, Weight: Optional[float] = 1.0) -> None: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsG1(self, theTf: float, theTl: float, theAngTol: float) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def Knot(self, Index: int) -> float: ...
	def KnotDistribution(self) -> GeomAbs_BSplKnotDistribution: ...
	@overload
	def KnotSequence(self, K: TColStd_Array1OfReal) -> None: ...
	@overload
	def KnotSequence(self) -> TColStd_Array1OfReal: ...
	@overload
	def Knots(self, K: TColStd_Array1OfReal) -> None: ...
	@overload
	def Knots(self) -> TColStd_Array1OfReal: ...
	def LastParameter(self) -> float: ...
	def LastUKnotIndex(self) -> int: ...
	def LocalD0(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt2d) -> None: ...
	def LocalD1(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def LocalD2(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def LocalD3(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def LocalDN(self, U: float, FromK1: int, ToK2: int, N: int) -> gp_Vec2d: ...
	def LocalValue(self, U: float, FromK1: int, ToK2: int) -> gp_Pnt2d: ...
	def LocateU(self, U: float, ParametricTolerance: float, WithKnotRepetition: Optional[bool] = False) -> Tuple[int, int]: ...
	@staticmethod
	def MaxDegree() -> int: ...
	def MovePoint(self, U: float, P: gp_Pnt2d, Index1: int, Index2: int) -> Tuple[int, int]: ...
	def MovePointAndTangent(self, U: float, P: gp_Pnt2d, Tangent: gp_Vec2d, Tolerance: float, StartingCondition: int, EndingCondition: int) -> int: ...
	@overload
	def Multiplicities(self, M: TColStd_Array1OfInteger) -> None: ...
	@overload
	def Multiplicities(self) -> TColStd_Array1OfInteger: ...
	def Multiplicity(self, Index: int) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def PeriodicNormalization(self) -> float: ...
	def Pole(self, Index: int) -> gp_Pnt2d: ...
	@overload
	def Poles(self, P: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	def Poles(self) -> TColgp_Array1OfPnt2d: ...
	def RemoveKnot(self, Index: int, M: int, Tolerance: float) -> bool: ...
	def RemovePole(self, Index: int) -> None: ...
	def Resolution(self, ToleranceUV: float) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def Segment(self, U1: float, U2: float, theTolerance: Optional[float] = precision_PConfusion()) -> None: ...
	@overload
	def SetKnot(self, Index: int, K: float) -> None: ...
	@overload
	def SetKnot(self, Index: int, K: float, M: int) -> None: ...
	def SetKnots(self, K: TColStd_Array1OfReal) -> None: ...
	def SetNotPeriodic(self) -> None: ...
	def SetOrigin(self, Index: int) -> None: ...
	def SetPeriodic(self) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt2d) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt2d, Weight: float) -> None: ...
	def SetWeight(self, Index: int, Weight: float) -> None: ...
	def StartPoint(self) -> gp_Pnt2d: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def Weight(self, Index: int) -> float: ...
	@overload
	def Weights(self, W: TColStd_Array1OfReal) -> None: ...
	@overload
	def Weights(self) -> TColStd_Array1OfReal: ...

class Geom2d_BezierCurve(Geom2d_BoundedCurve):
	@overload
	def __init__(self, CurvePoles: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	def __init__(self, CurvePoles: TColgp_Array1OfPnt2d, PoleWeights: TColStd_Array1OfReal) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Degree(self) -> int: ...
	def EndPoint(self) -> gp_Pnt2d: ...
	def FirstParameter(self) -> float: ...
	def Increase(self, Degree: int) -> None: ...
	def InsertPoleAfter(self, Index: int, P: gp_Pnt2d, Weight: Optional[float] = 1.0) -> None: ...
	def InsertPoleBefore(self, Index: int, P: gp_Pnt2d, Weight: Optional[float] = 1.0) -> None: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	@staticmethod
	def MaxDegree() -> int: ...
	def NbPoles(self) -> int: ...
	def Pole(self, Index: int) -> gp_Pnt2d: ...
	@overload
	def Poles(self, P: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	def Poles(self) -> TColgp_Array1OfPnt2d: ...
	def RemovePole(self, Index: int) -> None: ...
	def Resolution(self, ToleranceUV: float) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def Segment(self, U1: float, U2: float) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt2d) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt2d, Weight: float) -> None: ...
	def SetWeight(self, Index: int, Weight: float) -> None: ...
	def StartPoint(self) -> gp_Pnt2d: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def Weight(self, Index: int) -> float: ...
	@overload
	def Weights(self, W: TColStd_Array1OfReal) -> None: ...
	@overload
	def Weights(self) -> TColStd_Array1OfReal: ...

class Geom2d_Circle(Geom2d_Conic):
	@overload
	def __init__(self, C: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, A: gp_Ax2d, Radius: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, A: gp_Ax22d, Radius: float) -> None: ...
	def Circ2d(self) -> gp_Circ2d: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Eccentricity(self) -> float: ...
	def FirstParameter(self) -> float: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Radius(self) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetCirc2d(self, C: gp_Circ2d) -> None: ...
	def SetRadius(self, R: float) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...

class Geom2d_Ellipse(Geom2d_Conic):
	@overload
	def __init__(self, E: gp_Elips2d) -> None: ...
	@overload
	def __init__(self, MajorAxis: gp_Ax2d, MajorRadius: float, MinorRadius: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax22d, MajorRadius: float, MinorRadius: float) -> None: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Directrix1(self) -> gp_Ax2d: ...
	def Directrix2(self) -> gp_Ax2d: ...
	def Eccentricity(self) -> float: ...
	def Elips2d(self) -> gp_Elips2d: ...
	def FirstParameter(self) -> float: ...
	def Focal(self) -> float: ...
	def Focus1(self) -> gp_Pnt2d: ...
	def Focus2(self) -> gp_Pnt2d: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def MajorRadius(self) -> float: ...
	def MinorRadius(self) -> float: ...
	def Parameter(self) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetElips2d(self, E: gp_Elips2d) -> None: ...
	def SetMajorRadius(self, MajorRadius: float) -> None: ...
	def SetMinorRadius(self, MinorRadius: float) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...

class Geom2d_Hyperbola(Geom2d_Conic):
	@overload
	def __init__(self, H: gp_Hypr2d) -> None: ...
	@overload
	def __init__(self, MajorAxis: gp_Ax2d, MajorRadius: float, MinorRadius: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax22d, MajorRadius: float, MinorRadius: float) -> None: ...
	def Asymptote1(self) -> gp_Ax2d: ...
	def Asymptote2(self) -> gp_Ax2d: ...
	def ConjugateBranch1(self) -> gp_Hypr2d: ...
	def ConjugateBranch2(self) -> gp_Hypr2d: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Directrix1(self) -> gp_Ax2d: ...
	def Directrix2(self) -> gp_Ax2d: ...
	def Eccentricity(self) -> float: ...
	def FirstParameter(self) -> float: ...
	def Focal(self) -> float: ...
	def Focus1(self) -> gp_Pnt2d: ...
	def Focus2(self) -> gp_Pnt2d: ...
	def Hypr2d(self) -> gp_Hypr2d: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def MajorRadius(self) -> float: ...
	def MinorRadius(self) -> float: ...
	def OtherBranch(self) -> gp_Hypr2d: ...
	def Parameter(self) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetHypr2d(self, H: gp_Hypr2d) -> None: ...
	def SetMajorRadius(self, MajorRadius: float) -> None: ...
	def SetMinorRadius(self, MinorRadius: float) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...

class Geom2d_Parabola(Geom2d_Conic):
	@overload
	def __init__(self, Prb: gp_Parab2d) -> None: ...
	@overload
	def __init__(self, MirrorAxis: gp_Ax2d, Focal: float, Sense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Axis: gp_Ax22d, Focal: float) -> None: ...
	@overload
	def __init__(self, D: gp_Ax2d, F: gp_Pnt2d) -> None: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Directrix(self) -> gp_Ax2d: ...
	def Eccentricity(self) -> float: ...
	def FirstParameter(self) -> float: ...
	def Focal(self) -> float: ...
	def Focus(self) -> gp_Pnt2d: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Parab2d(self) -> gp_Parab2d: ...
	def Parameter(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf2d) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetFocal(self, Focal: float) -> None: ...
	def SetParab2d(self, Prb: gp_Parab2d) -> None: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf2d) -> float: ...

class Geom2d_TrimmedCurve(Geom2d_BoundedCurve):
	def __init__(self, C: Geom2d_Curve, U1: float, U2: float, Sense: Optional[bool] = True, theAdjustPeriodic: Optional[bool] = True) -> None: ...
	def BasisCurve(self) -> Geom2d_Curve: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom2d_Geometry: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def EndPoint(self) -> gp_Pnt2d: ...
	def FirstParameter(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf2d) -> float: ...
	def Period(self) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetTrim(self, U1: float, U2: float, Sense: Optional[bool] = True, theAdjustPeriodic: Optional[bool] = True) -> None: ...
	def StartPoint(self) -> gp_Pnt2d: ...
	def Transform(self, T: gp_Trsf2d) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf2d) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

Geom2d_BSplineCurve_MaxDegree = Geom2d_BSplineCurve.MaxDegree
Geom2d_BezierCurve_MaxDegree = Geom2d_BezierCurve.MaxDegree



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *

#the following typedef cannot be wrapped as is
TopTrans_Array2OfOrientation = NewType('TopTrans_Array2OfOrientation', Any)

class TopTrans_CurveTransition:
	def __init__(self) -> None: ...
	def Compare(self, Tole: float, Tang: gp_Dir, Norm: gp_Dir, Curv: float, S: TopAbs_Orientation, Or: TopAbs_Orientation) -> None: ...
	@overload
	def Reset(self, Tgt: gp_Dir, Norm: gp_Dir, Curv: float) -> None: ...
	@overload
	def Reset(self, Tgt: gp_Dir) -> None: ...
	def StateAfter(self) -> TopAbs_State: ...
	def StateBefore(self) -> TopAbs_State: ...

class TopTrans_SurfaceTransition:
	def __init__(self) -> None: ...
	@overload
	def Compare(self, Tole: float, Norm: gp_Dir, MaxD: gp_Dir, MinD: gp_Dir, MaxCurv: float, MinCurv: float, S: TopAbs_Orientation, O: TopAbs_Orientation) -> None: ...
	@overload
	def Compare(self, Tole: float, Norm: gp_Dir, S: TopAbs_Orientation, O: TopAbs_Orientation) -> None: ...
	@staticmethod
	def GetAfter(Tran: TopAbs_Orientation) -> TopAbs_State: ...
	@staticmethod
	def GetBefore(Tran: TopAbs_Orientation) -> TopAbs_State: ...
	@overload
	def Reset(self, Tgt: gp_Dir, Norm: gp_Dir, MaxD: gp_Dir, MinD: gp_Dir, MaxCurv: float, MinCurv: float) -> None: ...
	@overload
	def Reset(self, Tgt: gp_Dir, Norm: gp_Dir) -> None: ...
	def StateAfter(self) -> TopAbs_State: ...
	def StateBefore(self) -> TopAbs_State: ...

# harray1 classes
# harray2 classes
# hsequence classes

TopTrans_SurfaceTransition_GetAfter = TopTrans_SurfaceTransition.GetAfter
TopTrans_SurfaceTransition_GetBefore = TopTrans_SurfaceTransition.GetBefore



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TopoDS import *


class XCAFNoteObjects_NoteObject(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theObj: XCAFNoteObjects_NoteObject) -> None: ...
	def GetPlane(self) -> gp_Ax2: ...
	def GetPoint(self) -> gp_Pnt: ...
	def GetPointText(self) -> gp_Pnt: ...
	def GetPresentation(self) -> TopoDS_Shape: ...
	def HasPlane(self) -> bool: ...
	def HasPoint(self) -> bool: ...
	def HasPointText(self) -> bool: ...
	def Reset(self) -> None: ...
	def SetPlane(self, thePlane: gp_Ax2) -> None: ...
	def SetPoint(self, thePnt: gp_Pnt) -> None: ...
	def SetPointText(self, thePnt: gp_Pnt) -> None: ...
	def SetPresentation(self, thePresentation: TopoDS_Shape) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.Geom import *
from OCC.Core.TColgp import *
from OCC.Core.TopAbs import *
from OCC.Core.BOPAlgo import *
from OCC.Core.TopTools import *
from OCC.Core.BRepBuilderAPI import *
from OCC.Core.TColGeom import *
from OCC.Core.LocOpe import *


class BRepFeat_Status(IntEnum):
	BRepFeat_NoError: int = ...
	BRepFeat_InvalidPlacement: int = ...
	BRepFeat_HoleTooLong: int = ...
BRepFeat_NoError = BRepFeat_Status.BRepFeat_NoError
BRepFeat_InvalidPlacement = BRepFeat_Status.BRepFeat_InvalidPlacement
BRepFeat_HoleTooLong = BRepFeat_Status.BRepFeat_HoleTooLong

class BRepFeat_StatusError(IntEnum):
	BRepFeat_OK: int = ...
	BRepFeat_BadDirect: int = ...
	BRepFeat_BadIntersect: int = ...
	BRepFeat_EmptyBaryCurve: int = ...
	BRepFeat_EmptyCutResult: int = ...
	BRepFeat_FalseSide: int = ...
	BRepFeat_IncDirection: int = ...
	BRepFeat_IncSlidFace: int = ...
	BRepFeat_IncParameter: int = ...
	BRepFeat_IncTypes: int = ...
	BRepFeat_IntervalOverlap: int = ...
	BRepFeat_InvFirstShape: int = ...
	BRepFeat_InvOption: int = ...
	BRepFeat_InvShape: int = ...
	BRepFeat_LocOpeNotDone: int = ...
	BRepFeat_LocOpeInvNotDone: int = ...
	BRepFeat_NoExtFace: int = ...
	BRepFeat_NoFaceProf: int = ...
	BRepFeat_NoGluer: int = ...
	BRepFeat_NoIntersectF: int = ...
	BRepFeat_NoIntersectU: int = ...
	BRepFeat_NoParts: int = ...
	BRepFeat_NoProjPt: int = ...
	BRepFeat_NotInitialized: int = ...
	BRepFeat_NotYetImplemented: int = ...
	BRepFeat_NullRealTool: int = ...
	BRepFeat_NullToolF: int = ...
	BRepFeat_NullToolU: int = ...
BRepFeat_OK = BRepFeat_StatusError.BRepFeat_OK
BRepFeat_BadDirect = BRepFeat_StatusError.BRepFeat_BadDirect
BRepFeat_BadIntersect = BRepFeat_StatusError.BRepFeat_BadIntersect
BRepFeat_EmptyBaryCurve = BRepFeat_StatusError.BRepFeat_EmptyBaryCurve
BRepFeat_EmptyCutResult = BRepFeat_StatusError.BRepFeat_EmptyCutResult
BRepFeat_FalseSide = BRepFeat_StatusError.BRepFeat_FalseSide
BRepFeat_IncDirection = BRepFeat_StatusError.BRepFeat_IncDirection
BRepFeat_IncSlidFace = BRepFeat_StatusError.BRepFeat_IncSlidFace
BRepFeat_IncParameter = BRepFeat_StatusError.BRepFeat_IncParameter
BRepFeat_IncTypes = BRepFeat_StatusError.BRepFeat_IncTypes
BRepFeat_IntervalOverlap = BRepFeat_StatusError.BRepFeat_IntervalOverlap
BRepFeat_InvFirstShape = BRepFeat_StatusError.BRepFeat_InvFirstShape
BRepFeat_InvOption = BRepFeat_StatusError.BRepFeat_InvOption
BRepFeat_InvShape = BRepFeat_StatusError.BRepFeat_InvShape
BRepFeat_LocOpeNotDone = BRepFeat_StatusError.BRepFeat_LocOpeNotDone
BRepFeat_LocOpeInvNotDone = BRepFeat_StatusError.BRepFeat_LocOpeInvNotDone
BRepFeat_NoExtFace = BRepFeat_StatusError.BRepFeat_NoExtFace
BRepFeat_NoFaceProf = BRepFeat_StatusError.BRepFeat_NoFaceProf
BRepFeat_NoGluer = BRepFeat_StatusError.BRepFeat_NoGluer
BRepFeat_NoIntersectF = BRepFeat_StatusError.BRepFeat_NoIntersectF
BRepFeat_NoIntersectU = BRepFeat_StatusError.BRepFeat_NoIntersectU
BRepFeat_NoParts = BRepFeat_StatusError.BRepFeat_NoParts
BRepFeat_NoProjPt = BRepFeat_StatusError.BRepFeat_NoProjPt
BRepFeat_NotInitialized = BRepFeat_StatusError.BRepFeat_NotInitialized
BRepFeat_NotYetImplemented = BRepFeat_StatusError.BRepFeat_NotYetImplemented
BRepFeat_NullRealTool = BRepFeat_StatusError.BRepFeat_NullRealTool
BRepFeat_NullToolF = BRepFeat_StatusError.BRepFeat_NullToolF
BRepFeat_NullToolU = BRepFeat_StatusError.BRepFeat_NullToolU

class BRepFeat_PerfSelection(IntEnum):
	BRepFeat_NoSelection: int = ...
	BRepFeat_SelectionFU: int = ...
	BRepFeat_SelectionU: int = ...
	BRepFeat_SelectionSh: int = ...
	BRepFeat_SelectionShU: int = ...
BRepFeat_NoSelection = BRepFeat_PerfSelection.BRepFeat_NoSelection
BRepFeat_SelectionFU = BRepFeat_PerfSelection.BRepFeat_SelectionFU
BRepFeat_SelectionU = BRepFeat_PerfSelection.BRepFeat_SelectionU
BRepFeat_SelectionSh = BRepFeat_PerfSelection.BRepFeat_SelectionSh
BRepFeat_SelectionShU = BRepFeat_PerfSelection.BRepFeat_SelectionShU

class brepfeat:
	@staticmethod
	def Barycenter(S: TopoDS_Shape, Pt: gp_Pnt) -> None: ...
	@staticmethod
	def FaceUntil(S: TopoDS_Shape, F: TopoDS_Face) -> None: ...
	@staticmethod
	def IsInside(F1: TopoDS_Face, F2: TopoDS_Face) -> bool: ...
	@staticmethod
	def ParametricBarycenter(S: TopoDS_Shape, C: Geom_Curve) -> float: ...
	@staticmethod
	def ParametricMinMax(S: TopoDS_Shape, C: Geom_Curve, Ori: Optional[bool] = False) -> Tuple[float, float, float, float, bool]: ...
	@staticmethod
	def SampleEdges(S: TopoDS_Shape, Pt: TColgp_SequenceOfPnt) -> None: ...
	@staticmethod
	def Tool(SRef: TopoDS_Shape, Fac: TopoDS_Face, Orf: TopAbs_Orientation) -> TopoDS_Solid: ...

class BRepFeat_Builder(BOPAlgo_BOP):
	def __init__(self) -> None: ...
	def CheckSolidImages(self) -> None: ...
	def Clear(self) -> None: ...
	@overload
	def FillRemoved(self) -> None: ...
	@overload
	def FillRemoved(self, theS: TopoDS_Shape, theM: TopTools_MapOfShape) -> None: ...
	@overload
	def Init(self, theShape: TopoDS_Shape) -> None: ...
	@overload
	def Init(self, theShape: TopoDS_Shape, theTool: TopoDS_Shape) -> None: ...
	def KeepPart(self, theS: TopoDS_Shape) -> None: ...
	def KeepParts(self, theIm: TopTools_ListOfShape) -> None: ...
	def PartsOfTool(self, theLT: TopTools_ListOfShape) -> None: ...
	def PerformResult(self) -> None: ...
	def RebuildEdge(self, theE: TopoDS_Shape, theF: TopoDS_Face, theME: TopTools_MapOfShape, aLEIm: TopTools_ListOfShape) -> None: ...
	def RebuildFaces(self) -> None: ...
	@overload
	def SetOperation(self, theFuse: int) -> None: ...
	@overload
	def SetOperation(self, theFuse: int, theFlag: bool) -> None: ...

class BRepFeat_Form(BRepBuilderAPI_MakeShape):
	def BarycCurve(self) -> Geom_Curve: ...
	def BasisShapeValid(self) -> None: ...
	def CurrentStatusError(self) -> BRepFeat_StatusError: ...
	def Curves(self, S: TColGeom_SequenceOfCurve) -> None: ...
	def FirstShape(self) -> TopTools_ListOfShape: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def GeneratedShapeValid(self) -> None: ...
	def GluedFacesValid(self) -> None: ...
	def IsDeleted(self, S: TopoDS_Shape) -> bool: ...
	def LastShape(self) -> TopTools_ListOfShape: ...
	def Modified(self, F: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def NewEdges(self) -> TopTools_ListOfShape: ...
	def PerfSelectionValid(self) -> None: ...
	def ShapeFromValid(self) -> None: ...
	def ShapeUntilValid(self) -> None: ...
	def SketchFaceValid(self) -> None: ...
	def TgtEdges(self) -> TopTools_ListOfShape: ...

class BRepFeat_Gluer(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Snew: TopoDS_Shape, Sbase: TopoDS_Shape) -> None: ...
	def BasisShape(self) -> TopoDS_Shape: ...
	@overload
	def Bind(self, Fnew: TopoDS_Face, Fbase: TopoDS_Face) -> None: ...
	@overload
	def Bind(self, Enew: TopoDS_Edge, Ebase: TopoDS_Edge) -> None: ...
	def Build(self) -> None: ...
	def GluedShape(self) -> TopoDS_Shape: ...
	def Init(self, Snew: TopoDS_Shape, Sbase: TopoDS_Shape) -> None: ...
	def IsDeleted(self, F: TopoDS_Shape) -> bool: ...
	def Modified(self, F: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def OpeType(self) -> LocOpe_Operation: ...

class BRepFeat_RibSlot(BRepBuilderAPI_MakeShape):
	@staticmethod
	def ChoiceOfFaces(faces: TopTools_ListOfShape, cc: Geom_Curve, par: float, bnd: float, Pln: Geom_Plane) -> TopoDS_Face: ...
	def CurrentStatusError(self) -> BRepFeat_StatusError: ...
	def FacesForDraft(self) -> TopTools_ListOfShape: ...
	def FirstShape(self) -> TopTools_ListOfShape: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	@staticmethod
	def IntPar(C: Geom_Curve, P: gp_Pnt) -> float: ...
	def IsDeleted(self, F: TopoDS_Shape) -> bool: ...
	def LastShape(self) -> TopTools_ListOfShape: ...
	def Modified(self, F: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def NewEdges(self) -> TopTools_ListOfShape: ...
	def TgtEdges(self) -> TopTools_ListOfShape: ...

class BRepFeat_SplitShape(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	@overload
	def Add(self, theEdges: TopTools_SequenceOfShape) -> bool: ...
	@overload
	def Add(self, W: TopoDS_Wire, F: TopoDS_Face) -> None: ...
	@overload
	def Add(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	@overload
	def Add(self, Comp: TopoDS_Compound, F: TopoDS_Face) -> None: ...
	@overload
	def Add(self, E: TopoDS_Edge, EOn: TopoDS_Edge) -> None: ...
	def Build(self) -> None: ...
	def DirectLeft(self) -> TopTools_ListOfShape: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def IsDeleted(self, S: TopoDS_Shape) -> bool: ...
	def Left(self) -> TopTools_ListOfShape: ...
	def Modified(self, F: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Right(self) -> TopTools_ListOfShape: ...
	def SetCheckInterior(self, ToCheckInterior: bool) -> None: ...

class BRepFeat_MakeCylindricalHole(BRepFeat_Builder):
	def __init__(self) -> None: ...
	def Build(self) -> None: ...
	@overload
	def Init(self, Axis: gp_Ax1) -> None: ...
	@overload
	def Init(self, S: TopoDS_Shape, Axis: gp_Ax1) -> None: ...
	@overload
	def Perform(self, Radius: float) -> None: ...
	@overload
	def Perform(self, Radius: float, PFrom: float, PTo: float, WithControl: Optional[bool] = True) -> None: ...
	def PerformBlind(self, Radius: float, Length: float, WithControl: Optional[bool] = True) -> None: ...
	def PerformThruNext(self, Radius: float, WithControl: Optional[bool] = True) -> None: ...
	def PerformUntilEnd(self, Radius: float, WithControl: Optional[bool] = True) -> None: ...
	def Status(self) -> BRepFeat_Status: ...

class BRepFeat_MakeDPrism(BRepFeat_Form):
	@overload
	def __init__(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Face, Skface: TopoDS_Face, Angle: float, Fuse: int, Modify: bool) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def Add(self, E: TopoDS_Edge, OnFace: TopoDS_Face) -> None: ...
	def BarycCurve(self) -> Geom_Curve: ...
	def BossEdges(self, sig: int) -> None: ...
	def Curves(self, S: TColGeom_SequenceOfCurve) -> None: ...
	def Init(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Face, Skface: TopoDS_Face, Angle: float, Fuse: int, Modify: bool) -> None: ...
	def LatEdges(self) -> TopTools_ListOfShape: ...
	@overload
	def Perform(self, Height: float) -> None: ...
	@overload
	def Perform(self, Until: TopoDS_Shape) -> None: ...
	@overload
	def Perform(self, From: TopoDS_Shape, Until: TopoDS_Shape) -> None: ...
	def PerformFromEnd(self, FUntil: TopoDS_Shape) -> None: ...
	def PerformThruAll(self) -> None: ...
	def PerformUntilEnd(self) -> None: ...
	def PerformUntilHeight(self, Until: TopoDS_Shape, Height: float) -> None: ...
	def TopEdges(self) -> TopTools_ListOfShape: ...

class BRepFeat_MakeLinearForm(BRepFeat_RibSlot):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Sbase: TopoDS_Shape, W: TopoDS_Wire, P: Geom_Plane, Direction: gp_Vec, Direction1: gp_Vec, Fuse: int, Modify: bool) -> None: ...
	def Add(self, E: TopoDS_Edge, OnFace: TopoDS_Face) -> None: ...
	def Init(self, Sbase: TopoDS_Shape, W: TopoDS_Wire, P: Geom_Plane, Direction: gp_Vec, Direction1: gp_Vec, Fuse: int, Modify: bool) -> None: ...
	def Perform(self) -> None: ...
	def Propagate(self, L: TopTools_ListOfShape, F: TopoDS_Face, FPoint: gp_Pnt, LPoint: gp_Pnt) -> Tuple[bool, bool]: ...

class BRepFeat_MakePipe(BRepFeat_Form):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Shape, Skface: TopoDS_Face, Spine: TopoDS_Wire, Fuse: int, Modify: bool) -> None: ...
	def Add(self, E: TopoDS_Edge, OnFace: TopoDS_Face) -> None: ...
	def BarycCurve(self) -> Geom_Curve: ...
	def Curves(self, S: TColGeom_SequenceOfCurve) -> None: ...
	def Init(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Shape, Skface: TopoDS_Face, Spine: TopoDS_Wire, Fuse: int, Modify: bool) -> None: ...
	@overload
	def Perform(self) -> None: ...
	@overload
	def Perform(self, Until: TopoDS_Shape) -> None: ...
	@overload
	def Perform(self, From: TopoDS_Shape, Until: TopoDS_Shape) -> None: ...

class BRepFeat_MakePrism(BRepFeat_Form):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Shape, Skface: TopoDS_Face, Direction: gp_Dir, Fuse: int, Modify: bool) -> None: ...
	def Add(self, E: TopoDS_Edge, OnFace: TopoDS_Face) -> None: ...
	def BarycCurve(self) -> Geom_Curve: ...
	def Curves(self, S: TColGeom_SequenceOfCurve) -> None: ...
	def Init(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Shape, Skface: TopoDS_Face, Direction: gp_Dir, Fuse: int, Modify: bool) -> None: ...
	@overload
	def Perform(self, Length: float) -> None: ...
	@overload
	def Perform(self, Until: TopoDS_Shape) -> None: ...
	@overload
	def Perform(self, From: TopoDS_Shape, Until: TopoDS_Shape) -> None: ...
	def PerformFromEnd(self, FUntil: TopoDS_Shape) -> None: ...
	def PerformThruAll(self) -> None: ...
	def PerformUntilEnd(self) -> None: ...
	def PerformUntilHeight(self, Until: TopoDS_Shape, Length: float) -> None: ...

class BRepFeat_MakeRevol(BRepFeat_Form):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Shape, Skface: TopoDS_Face, Axis: gp_Ax1, Fuse: int, Modify: bool) -> None: ...
	def Add(self, E: TopoDS_Edge, OnFace: TopoDS_Face) -> None: ...
	def BarycCurve(self) -> Geom_Curve: ...
	def Curves(self, S: TColGeom_SequenceOfCurve) -> None: ...
	def Init(self, Sbase: TopoDS_Shape, Pbase: TopoDS_Shape, Skface: TopoDS_Face, Axis: gp_Ax1, Fuse: int, Modify: bool) -> None: ...
	@overload
	def Perform(self, Angle: float) -> None: ...
	@overload
	def Perform(self, Until: TopoDS_Shape) -> None: ...
	@overload
	def Perform(self, From: TopoDS_Shape, Until: TopoDS_Shape) -> None: ...
	def PerformThruAll(self) -> None: ...
	def PerformUntilAngle(self, Until: TopoDS_Shape, Angle: float) -> None: ...

class BRepFeat_MakeRevolutionForm(BRepFeat_RibSlot):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Sbase: TopoDS_Shape, W: TopoDS_Wire, Plane: Geom_Plane, Axis: gp_Ax1, Height1: float, Height2: float, Fuse: int) -> bool: ...
	def Add(self, E: TopoDS_Edge, OnFace: TopoDS_Face) -> None: ...
	def Init(self, Sbase: TopoDS_Shape, W: TopoDS_Wire, Plane: Geom_Plane, Axis: gp_Ax1, Height1: float, Height2: float, Fuse: int) -> bool: ...
	def Perform(self) -> None: ...
	def Propagate(self, L: TopTools_ListOfShape, F: TopoDS_Face, FPoint: gp_Pnt, LPoint: gp_Pnt) -> Tuple[bool, bool]: ...

# harray1 classes
# harray2 classes
# hsequence classes

brepfeat_Barycenter = brepfeat.Barycenter
brepfeat_FaceUntil = brepfeat.FaceUntil
brepfeat_IsInside = brepfeat.IsInside
brepfeat_ParametricBarycenter = brepfeat.ParametricBarycenter
brepfeat_ParametricMinMax = brepfeat.ParametricMinMax
brepfeat_Print = brepfeat.Print
brepfeat_SampleEdges = brepfeat.SampleEdges
brepfeat_Tool = brepfeat.Tool
BRepFeat_RibSlot_ChoiceOfFaces = BRepFeat_RibSlot.ChoiceOfFaces
BRepFeat_RibSlot_IntPar = BRepFeat_RibSlot.IntPar



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMNaming module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmnaming.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMNaming
else:
    import _XmlMNaming

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMNaming.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMNaming.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMNaming.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMNaming.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMNaming.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMNaming.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMNaming.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMNaming.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMNaming:
_XmlMNaming.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMNaming.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage
import OCC.Core.TopTools
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMNaming_NamedShapeDriver_Create() -> "opencascade::handle< XmlMNaming_NamedShapeDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamedShapeDriver_Create()

def Handle_XmlMNaming_NamedShapeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMNaming_NamedShapeDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamedShapeDriver_DownCast(t)

def Handle_XmlMNaming_NamedShapeDriver_IsNull(t: "opencascade::handle< XmlMNaming_NamedShapeDriver > const &") -> "bool":
    return _XmlMNaming.Handle_XmlMNaming_NamedShapeDriver_IsNull(t)

def Handle_XmlMNaming_NamingDriver_Create() -> "opencascade::handle< XmlMNaming_NamingDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamingDriver_Create()

def Handle_XmlMNaming_NamingDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMNaming_NamingDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamingDriver_DownCast(t)

def Handle_XmlMNaming_NamingDriver_IsNull(t: "opencascade::handle< XmlMNaming_NamingDriver > const &") -> "bool":
    return _XmlMNaming.Handle_XmlMNaming_NamingDriver_IsNull(t)
class xmlmnaming(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        aMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMNaming.xmlmnaming_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMNaming.xmlmnaming_swiginit(self, _XmlMNaming.new_xmlmnaming())
    __swig_destroy__ = _XmlMNaming.delete_xmlmnaming

# Register xmlmnaming in _XmlMNaming:
_XmlMNaming.xmlmnaming_swigregister(xmlmnaming)

def xmlmnaming_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    aMessageDriver: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMNaming.xmlmnaming_AddDrivers(*args)

class XmlMNaming_NamedShapeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        aMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMNaming.XmlMNaming_NamedShapeDriver_swiginit(self, _XmlMNaming.new_XmlMNaming_NamedShapeDriver(*args))

    def Clear(self, *args) -> "void":
        r"""
        Clear myshapeset.

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_Clear(self, *args)

    def GetShapesLocations(self, *args) -> "TopTools_LocationSet &":
        r"""
        Get the format of topology.

        Returns
        -------
        TopTools_LocationSet

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_GetShapesLocations(self, *args)

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_Paste(self, *args)

    def ReadShapeSection(self, *args) -> "void":
        r"""
        Input the shapes from dom element.

        Parameters
        ----------
        anElement: XmlObjMgt_Element
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_ReadShapeSection(self, *args)

    def WriteShapeSection(self, *args) -> "void":
        r"""
        Output the shapes into dom element.

        Parameters
        ----------
        anElement: XmlObjMgt_Element
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_WriteShapeSection(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMNaming_NamedShapeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMNaming.delete_XmlMNaming_NamedShapeDriver

# Register XmlMNaming_NamedShapeDriver in _XmlMNaming:
_XmlMNaming.XmlMNaming_NamedShapeDriver_swigregister(XmlMNaming_NamedShapeDriver)

class XmlMNaming_NamingDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        aMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMNaming.XmlMNaming_NamingDriver_swiginit(self, _XmlMNaming.new_XmlMNaming_NamingDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamingDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMNaming_NamingDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMNaming.delete_XmlMNaming_NamingDriver

# Register XmlMNaming_NamingDriver in _XmlMNaming:
_XmlMNaming.XmlMNaming_NamingDriver_swigregister(XmlMNaming_NamingDriver)

class XmlMNaming_Shape1(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Doc: XmlObjMgt_Document

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        E: XmlObjMgt_Element

        Returns
        -------
        None

        """
        _XmlMNaming.XmlMNaming_Shape1_swiginit(self, _XmlMNaming.new_XmlMNaming_Shape1(*args))

    def Element(self, *args) -> "XmlObjMgt_Element const &":
        r"""
        Return myelement.

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlMNaming.XmlMNaming_Shape1_Element(self, *args)

    def LocId(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _XmlMNaming.XmlMNaming_Shape1_LocId(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation

        """
        return _XmlMNaming.XmlMNaming_Shape1_Orientation(self, *args)

    def SetShape(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ID: int
        LocID: int
        Orient: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_Shape1_SetShape(self, *args)

    def SetVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theVertex: TopoDS_Shape

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_Shape1_SetVertex(self, *args)

    def TShapeId(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _XmlMNaming.XmlMNaming_Shape1_TShapeId(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMNaming.delete_XmlMNaming_Shape1

# Register XmlMNaming_Shape1 in _XmlMNaming:
_XmlMNaming.XmlMNaming_Shape1_swigregister(XmlMNaming_Shape1)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.TColgp import *
from OCC.Core.BVH import *


class Bnd_Array1OfBox:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> Bnd_Box: ...
    def __setitem__(self, index: int, value: Bnd_Box) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[Bnd_Box]: ...
    def next(self) -> Bnd_Box: ...
    __next__ = next
    def Init(self, theValue: Bnd_Box) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> Bnd_Box: ...
    def Last(self) -> Bnd_Box: ...
    def Value(self, theIndex: int) -> Bnd_Box: ...
    def SetValue(self, theIndex: int, theValue: Bnd_Box) -> None: ...

class Bnd_Array1OfBox2d:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> Bnd_Box2d: ...
    def __setitem__(self, index: int, value: Bnd_Box2d) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[Bnd_Box2d]: ...
    def next(self) -> Bnd_Box2d: ...
    __next__ = next
    def Init(self, theValue: Bnd_Box2d) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> Bnd_Box2d: ...
    def Last(self) -> Bnd_Box2d: ...
    def Value(self, theIndex: int) -> Bnd_Box2d: ...
    def SetValue(self, theIndex: int, theValue: Bnd_Box2d) -> None: ...

class Bnd_Array1OfSphere:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> Bnd_Sphere: ...
    def __setitem__(self, index: int, value: Bnd_Sphere) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[Bnd_Sphere]: ...
    def next(self) -> Bnd_Sphere: ...
    __next__ = next
    def Init(self, theValue: Bnd_Sphere) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> Bnd_Sphere: ...
    def Last(self) -> Bnd_Sphere: ...
    def Value(self, theIndex: int) -> Bnd_Sphere: ...
    def SetValue(self, theIndex: int, theValue: Bnd_Sphere) -> None: ...

class Bnd_SeqOfBox:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Bnd_Box: ...
    def Last(self) -> Bnd_Box: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Bnd_Box) -> Bnd_Box: ...
    def Prepend(self, theItem: Bnd_Box) -> Bnd_Box: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Bnd_Box: ...
    def SetValue(self, theIndex: int, theValue: Bnd_Box) -> None: ...

class Bnd_B2d:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theCenter: gp_XY, theHSize: gp_XY) -> None: ...
	@overload
	def Add(self, thePnt: gp_XY) -> None: ...
	@overload
	def Add(self, thePnt: gp_Pnt2d) -> None: ...
	@overload
	def Add(self, theBox: Bnd_B2d) -> None: ...
	def Clear(self) -> None: ...
	def CornerMax(self) -> gp_XY: ...
	def CornerMin(self) -> gp_XY: ...
	def Enlarge(self, theDiff: float) -> None: ...
	@overload
	def IsIn(self, theBox: Bnd_B2d) -> bool: ...
	@overload
	def IsIn(self, theBox: Bnd_B2d, theTrsf: gp_Trsf2d) -> bool: ...
	@overload
	def IsOut(self, thePnt: gp_XY) -> bool: ...
	@overload
	def IsOut(self, theCenter: gp_XY, theRadius: float, isCircleHollow: Optional[bool] = False) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B2d) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B2d, theTrsf: gp_Trsf2d) -> bool: ...
	@overload
	def IsOut(self, theLine: gp_Ax2d) -> bool: ...
	@overload
	def IsOut(self, theP0: gp_XY, theP1: gp_XY) -> bool: ...
	def IsVoid(self) -> bool: ...
	def Limit(self, theOtherBox: Bnd_B2d) -> bool: ...
	def SetCenter(self, theCenter: gp_XY) -> None: ...
	def SetHSize(self, theHSize: gp_XY) -> None: ...
	def SquareExtent(self) -> float: ...
	def Transformed(self, theTrsf: gp_Trsf2d) -> Bnd_B2d: ...

class Bnd_B2f:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theCenter: gp_XY, theHSize: gp_XY) -> None: ...
	@overload
	def Add(self, thePnt: gp_XY) -> None: ...
	@overload
	def Add(self, thePnt: gp_Pnt2d) -> None: ...
	@overload
	def Add(self, theBox: Bnd_B2f) -> None: ...
	def Clear(self) -> None: ...
	def CornerMax(self) -> gp_XY: ...
	def CornerMin(self) -> gp_XY: ...
	def Enlarge(self, theDiff: float) -> None: ...
	@overload
	def IsIn(self, theBox: Bnd_B2f) -> bool: ...
	@overload
	def IsIn(self, theBox: Bnd_B2f, theTrsf: gp_Trsf2d) -> bool: ...
	@overload
	def IsOut(self, thePnt: gp_XY) -> bool: ...
	@overload
	def IsOut(self, theCenter: gp_XY, theRadius: float, isCircleHollow: Optional[bool] = False) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B2f) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B2f, theTrsf: gp_Trsf2d) -> bool: ...
	@overload
	def IsOut(self, theLine: gp_Ax2d) -> bool: ...
	@overload
	def IsOut(self, theP0: gp_XY, theP1: gp_XY) -> bool: ...
	def IsVoid(self) -> bool: ...
	def Limit(self, theOtherBox: Bnd_B2f) -> bool: ...
	def SetCenter(self, theCenter: gp_XY) -> None: ...
	def SetHSize(self, theHSize: gp_XY) -> None: ...
	def SquareExtent(self) -> float: ...
	def Transformed(self, theTrsf: gp_Trsf2d) -> Bnd_B2f: ...

class Bnd_B3d:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theCenter: gp_XYZ, theHSize: gp_XYZ) -> None: ...
	@overload
	def Add(self, thePnt: gp_XYZ) -> None: ...
	@overload
	def Add(self, thePnt: gp_Pnt) -> None: ...
	@overload
	def Add(self, theBox: Bnd_B3d) -> None: ...
	def Clear(self) -> None: ...
	def CornerMax(self) -> gp_XYZ: ...
	def CornerMin(self) -> gp_XYZ: ...
	def Enlarge(self, theDiff: float) -> None: ...
	@overload
	def IsIn(self, theBox: Bnd_B3d) -> bool: ...
	@overload
	def IsIn(self, theBox: Bnd_B3d, theTrsf: gp_Trsf) -> bool: ...
	@overload
	def IsOut(self, thePnt: gp_XYZ) -> bool: ...
	@overload
	def IsOut(self, theCenter: gp_XYZ, theRadius: float, isSphereHollow: Optional[bool] = False) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B3d) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B3d, theTrsf: gp_Trsf) -> bool: ...
	@overload
	def IsOut(self, theLine: gp_Ax1, isRay: Optional[bool] = False, theOverthickness: Optional[float] = 0.0) -> bool: ...
	@overload
	def IsOut(self, thePlane: gp_Ax3) -> bool: ...
	def IsVoid(self) -> bool: ...
	def Limit(self, theOtherBox: Bnd_B3d) -> bool: ...
	def SetCenter(self, theCenter: gp_XYZ) -> None: ...
	def SetHSize(self, theHSize: gp_XYZ) -> None: ...
	def SquareExtent(self) -> float: ...
	def Transformed(self, theTrsf: gp_Trsf) -> Bnd_B3d: ...

class Bnd_B3f:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theCenter: gp_XYZ, theHSize: gp_XYZ) -> None: ...
	@overload
	def Add(self, thePnt: gp_XYZ) -> None: ...
	@overload
	def Add(self, thePnt: gp_Pnt) -> None: ...
	@overload
	def Add(self, theBox: Bnd_B3f) -> None: ...
	def Clear(self) -> None: ...
	def CornerMax(self) -> gp_XYZ: ...
	def CornerMin(self) -> gp_XYZ: ...
	def Enlarge(self, theDiff: float) -> None: ...
	@overload
	def IsIn(self, theBox: Bnd_B3f) -> bool: ...
	@overload
	def IsIn(self, theBox: Bnd_B3f, theTrsf: gp_Trsf) -> bool: ...
	@overload
	def IsOut(self, thePnt: gp_XYZ) -> bool: ...
	@overload
	def IsOut(self, theCenter: gp_XYZ, theRadius: float, isSphereHollow: Optional[bool] = False) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B3f) -> bool: ...
	@overload
	def IsOut(self, theOtherBox: Bnd_B3f, theTrsf: gp_Trsf) -> bool: ...
	@overload
	def IsOut(self, theLine: gp_Ax1, isRay: Optional[bool] = False, theOverthickness: Optional[float] = 0.0) -> bool: ...
	@overload
	def IsOut(self, thePlane: gp_Ax3) -> bool: ...
	def IsVoid(self) -> bool: ...
	def Limit(self, theOtherBox: Bnd_B3f) -> bool: ...
	def SetCenter(self, theCenter: gp_XYZ) -> None: ...
	def SetHSize(self, theHSize: gp_XYZ) -> None: ...
	def SquareExtent(self) -> float: ...
	def Transformed(self, theTrsf: gp_Trsf) -> Bnd_B3f: ...

class Bnd_BoundSortBox:
	def __init__(self) -> None: ...
	def Add(self, theBox: Bnd_Box, boxIndex: int) -> None: ...
	@overload
	def Compare(self, theBox: Bnd_Box) -> TColStd_ListOfInteger: ...
	@overload
	def Compare(self, P: gp_Pln) -> TColStd_ListOfInteger: ...
	def Destroy(self) -> None: ...
	def Dump(self) -> None: ...
	@overload
	def Initialize(self, CompleteBox: Bnd_Box, SetOfBox: Bnd_HArray1OfBox) -> None: ...
	@overload
	def Initialize(self, SetOfBox: Bnd_HArray1OfBox) -> None: ...
	@overload
	def Initialize(self, CompleteBox: Bnd_Box, nbComponents: int) -> None: ...

class Bnd_BoundSortBox2d:
	def __init__(self) -> None: ...
	def Add(self, theBox: Bnd_Box2d, boxIndex: int) -> None: ...
	def Compare(self, theBox: Bnd_Box2d) -> TColStd_ListOfInteger: ...
	def Dump(self) -> None: ...
	@overload
	def Initialize(self, CompleteBox: Bnd_Box2d, SetOfBox: Bnd_HArray1OfBox2d) -> None: ...
	@overload
	def Initialize(self, SetOfBox: Bnd_HArray1OfBox2d) -> None: ...
	@overload
	def Initialize(self, CompleteBox: Bnd_Box2d, nbComponents: int) -> None: ...

class Bnd_Box:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theMin: gp_Pnt, theMax: gp_Pnt) -> None: ...
	@overload
	def Add(self, Other: Bnd_Box) -> None: ...
	@overload
	def Add(self, P: gp_Pnt) -> None: ...
	@overload
	def Add(self, P: gp_Pnt, D: gp_Dir) -> None: ...
	@overload
	def Add(self, D: gp_Dir) -> None: ...
	def CornerMax(self) -> gp_Pnt: ...
	def CornerMin(self) -> gp_Pnt: ...
	def Distance(self, Other: Bnd_Box) -> float: ...
	def Dump(self) -> None: ...
	def Enlarge(self, Tol: float) -> None: ...
	def FinitePart(self) -> Bnd_Box: ...
	def Get(self) -> Tuple[float, float, float, float, float, float]: ...
	def GetGap(self) -> float: ...
	def HasFinitePart(self) -> bool: ...
	def InitFromJson(self, theSStream: Standard_SStream) -> Tuple[bool, int]: ...
	def IsOpen(self) -> bool: ...
	def IsOpenXmax(self) -> bool: ...
	def IsOpenXmin(self) -> bool: ...
	def IsOpenYmax(self) -> bool: ...
	def IsOpenYmin(self) -> bool: ...
	def IsOpenZmax(self) -> bool: ...
	def IsOpenZmin(self) -> bool: ...
	@overload
	def IsOut(self, P: gp_Pnt) -> bool: ...
	@overload
	def IsOut(self, L: gp_Lin) -> bool: ...
	@overload
	def IsOut(self, P: gp_Pln) -> bool: ...
	@overload
	def IsOut(self, Other: Bnd_Box) -> bool: ...
	@overload
	def IsOut(self, Other: Bnd_Box, T: gp_Trsf) -> bool: ...
	@overload
	def IsOut(self, T1: gp_Trsf, Other: Bnd_Box, T2: gp_Trsf) -> bool: ...
	@overload
	def IsOut(self, P1: gp_Pnt, P2: gp_Pnt, D: gp_Dir) -> bool: ...
	def IsThin(self, tol: float) -> bool: ...
	def IsVoid(self) -> bool: ...
	def IsWhole(self) -> bool: ...
	def IsXThin(self, tol: float) -> bool: ...
	def IsYThin(self, tol: float) -> bool: ...
	def IsZThin(self, tol: float) -> bool: ...
	def OpenXmax(self) -> None: ...
	def OpenXmin(self) -> None: ...
	def OpenYmax(self) -> None: ...
	def OpenYmin(self) -> None: ...
	def OpenZmax(self) -> None: ...
	def OpenZmin(self) -> None: ...
	@overload
	def Set(self, P: gp_Pnt) -> None: ...
	@overload
	def Set(self, P: gp_Pnt, D: gp_Dir) -> None: ...
	def SetGap(self, Tol: float) -> None: ...
	def SetVoid(self) -> None: ...
	def SetWhole(self) -> None: ...
	def SquareExtent(self) -> float: ...
	def Transformed(self, T: gp_Trsf) -> Bnd_Box: ...
	@overload
	def Update(self, aXmin: float, aYmin: float, aZmin: float, aXmax: float, aYmax: float, aZmax: float) -> None: ...
	@overload
	def Update(self, X: float, Y: float, Z: float) -> None: ...

class Bnd_Box2d:
	def __init__(self) -> None: ...
	@overload
	def Add(self, Other: Bnd_Box2d) -> None: ...
	@overload
	def Add(self, thePnt: gp_Pnt2d) -> None: ...
	@overload
	def Add(self, thePnt: gp_Pnt2d, theDir: gp_Dir2d) -> None: ...
	@overload
	def Add(self, D: gp_Dir2d) -> None: ...
	def Dump(self) -> None: ...
	def Enlarge(self, theTol: float) -> None: ...
	def Get(self) -> Tuple[float, float, float, float]: ...
	def GetGap(self) -> float: ...
	def IsOpenXmax(self) -> bool: ...
	def IsOpenXmin(self) -> bool: ...
	def IsOpenYmax(self) -> bool: ...
	def IsOpenYmin(self) -> bool: ...
	@overload
	def IsOut(self, P: gp_Pnt2d) -> bool: ...
	@overload
	def IsOut(self, Other: Bnd_Box2d) -> bool: ...
	@overload
	def IsOut(self, theOther: Bnd_Box2d, theTrsf: gp_Trsf2d) -> bool: ...
	@overload
	def IsOut(self, T1: gp_Trsf2d, Other: Bnd_Box2d, T2: gp_Trsf2d) -> bool: ...
	def IsVoid(self) -> bool: ...
	def IsWhole(self) -> bool: ...
	def OpenXmax(self) -> None: ...
	def OpenXmin(self) -> None: ...
	def OpenYmax(self) -> None: ...
	def OpenYmin(self) -> None: ...
	@overload
	def Set(self, thePnt: gp_Pnt2d) -> None: ...
	@overload
	def Set(self, thePnt: gp_Pnt2d, theDir: gp_Dir2d) -> None: ...
	def SetGap(self, Tol: float) -> None: ...
	def SetVoid(self) -> None: ...
	def SetWhole(self) -> None: ...
	def SquareExtent(self) -> float: ...
	def Transformed(self, T: gp_Trsf2d) -> Bnd_Box2d: ...
	@overload
	def Update(self, aXmin: float, aYmin: float, aXmax: float, aYmax: float) -> None: ...
	@overload
	def Update(self, X: float, Y: float) -> None: ...

class Bnd_OBB:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theCenter: gp_Pnt, theXDirection: gp_Dir, theYDirection: gp_Dir, theZDirection: gp_Dir, theHXSize: float, theHYSize: float, theHZSize: float) -> None: ...
	@overload
	def __init__(self, theBox: Bnd_Box) -> None: ...
	@overload
	def Add(self, theOther: Bnd_OBB) -> None: ...
	@overload
	def Add(self, theP: gp_Pnt) -> None: ...
	def Center(self) -> gp_XYZ: ...
	def Enlarge(self, theGapAdd: float) -> None: ...
	def GetVertex(self, theP_list: List[gp_Pnt]) -> bool: ...
	def IsAABox(self) -> bool: ...
	def IsCompletelyInside(self, theOther: Bnd_OBB) -> bool: ...
	@overload
	def IsOut(self, theOther: Bnd_OBB) -> bool: ...
	@overload
	def IsOut(self, theP: gp_Pnt) -> bool: ...
	def IsVoid(self) -> bool: ...
	def Position(self) -> gp_Ax3: ...
	def ReBuild(self, theListOfPoints: TColgp_Array1OfPnt, theListOfTolerances: Optional[TColStd_Array1OfReal] = 0, theIsOptimal: Optional[bool] = False) -> None: ...
	def SetAABox(self, theFlag: bool) -> None: ...
	def SetCenter(self, theCenter: gp_Pnt) -> None: ...
	def SetVoid(self) -> None: ...
	def SetXComponent(self, theXDirection: gp_Dir, theHXSize: float) -> None: ...
	def SetYComponent(self, theYDirection: gp_Dir, theHYSize: float) -> None: ...
	def SetZComponent(self, theZDirection: gp_Dir, theHZSize: float) -> None: ...
	def SquareExtent(self) -> float: ...
	def XDirection(self) -> gp_XYZ: ...
	def XHSize(self) -> float: ...
	def YDirection(self) -> gp_XYZ: ...
	def YHSize(self) -> float: ...
	def ZDirection(self) -> gp_XYZ: ...
	def ZHSize(self) -> float: ...

class Bnd_Range:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theMin: float, theMax: float) -> None: ...
	@overload
	def Add(self, theParameter: float) -> None: ...
	@overload
	def Add(self, theRange: Bnd_Range) -> None: ...
	def Common(self, theOther: Bnd_Range) -> None: ...
	def Delta(self) -> float: ...
	def Enlarge(self, theDelta: float) -> None: ...
	def GetBounds(self) -> Tuple[bool, float, float]: ...
	def GetIntermediatePoint(self, theLambda: float) -> Tuple[bool, float]: ...
	def GetMax(self) -> Tuple[bool, float]: ...
	def GetMin(self) -> Tuple[bool, float]: ...
	def IsIntersected(self, theVal: float, thePeriod: Optional[float] = 0.0) -> int: ...
	@overload
	def IsOut(self, theValue: float) -> bool: ...
	@overload
	def IsOut(self, theRange: Bnd_Range) -> bool: ...
	def IsVoid(self) -> bool: ...
	def SetVoid(self) -> None: ...
	def Shift(self, theVal: float) -> None: ...
	def Shifted(self, theVal: float) -> Bnd_Range: ...
	def TrimFrom(self, theValLower: float) -> None: ...
	def TrimTo(self, theValUpper: float) -> None: ...
	def Union(self, theOther: Bnd_Range) -> bool: ...

class Bnd_Sphere:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theCntr: gp_XYZ, theRad: float, theU: int, theV: int) -> None: ...
	def Add(self, theOther: Bnd_Sphere) -> None: ...
	def Center(self) -> gp_XYZ: ...
	def Distance(self, theNode: gp_XYZ) -> float: ...
	def Distances(self, theXYZ: gp_XYZ) -> Tuple[float, float]: ...
	@overload
	def IsOut(self, theOther: Bnd_Sphere) -> bool: ...
	@overload
	def IsOut(self, thePnt: gp_XYZ) -> Tuple[bool, float]: ...
	def IsValid(self) -> bool: ...
	def Project(self, theNode: gp_XYZ, theProjNode: gp_XYZ) -> Tuple[bool, float, bool]: ...
	def Radius(self) -> float: ...
	def SetValid(self, isValid: bool) -> None: ...
	def SquareDistance(self, theNode: gp_XYZ) -> float: ...
	def SquareDistances(self, theXYZ: gp_XYZ) -> Tuple[float, float]: ...
	def SquareExtent(self) -> float: ...
	def U(self) -> int: ...
	def V(self) -> int: ...

class Bnd_Tools:
	@overload
	@staticmethod
	def Bnd2BVH(theBox: Bnd_Box2d) -> False: ...
	@overload
	@staticmethod
	def Bnd2BVH(theBox: Bnd_Box) -> False: ...

# harray1 classes

class Bnd_HArray1OfBox(Bnd_Array1OfBox, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Bnd_Array1OfBox: ...


class Bnd_HArray1OfSphere(Bnd_Array1OfSphere, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Bnd_Array1OfSphere: ...


class Bnd_HArray1OfBox2d(Bnd_Array1OfBox2d, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Bnd_Array1OfBox2d: ...

# harray2 classes
# hsequence classes

Bnd_Tools_Bnd2BVH = Bnd_Tools.Bnd2BVH
Bnd_Tools_Bnd2BVH = Bnd_Tools.Bnd2BVH
